@@ -876,6 +876,21 @@ class PipelineEndpointLauncher:
         print("pipeline_endpoint_by_name.endpoint : ", rest_endpoint)
         _ = requests.post(rest_endpoint, headers=auth_header, json=json_data)
 
+class TextSampledDataBuilder:
+    def build(self, sampled_data):
+        assert(isinstance(sampled_data, list) == True, "sampled_data must be a list")
+        samped_json_data = []
+        for item in sampled_data:
+            json_data = {}
+            json_data["id"] = item[0]
+            json_data["text"] = item[1]
+            json_data["value"] = item[2]
+            json_data["strategy"] = item[3]
+            json_data["score"] = item[4] 
+            samped_json_data.append(json_data)
+        return samped_json_data
+
+
 class SampledDataDispatcher:
     def __init__(self, config):
         self.config = config
